package net.geraldloeffler.tasktracker2006.domain;

import java.io.Serializable;
import java.util.LinkedHashSet;
import java.util.Set;
import javax.xml.bind.annotation.AccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlTransient;

/**
 * Non-persistent Project domain classs mapped to XML via JAXB annotations.
 * A Project is composed of an arbitrary number
 * of Tasks.
 * 
 * @author Gerald Loeffler
 */
@XmlAccessorType(AccessType.FIELD)
public class Project implements Serializable {
  private static final long serialVersionUID = 1L;
  
  private Integer   id;
  private String    name;
  private String    description;
  @XmlTransient
  private Set<Task> tasks = new LinkedHashSet<Task>();

  /** required no-arg constructor (but package-scoped) */
  Project() {}

  /** Minimal constructor */
  public Project(String name) {
    setName(name);
  }

  public Integer getId() {
    return id;
  }

  public String getName() {
    return name;
  }

  private void setName(String name) {
    if (name == null) throw new IllegalArgumentException("name is null");
    this.name = name;
  }

  public String getDescription() {
    return description;
  }

  public void setDescription(String description) {
    this.description = description;
  }

  public Set<Task> getTasks() {
    return tasks;
  }
  
  @Override
  public String toString() {
    return this.getClass().getSimpleName() + "[id=" + getId() + "]";
  }
}
