package net.geraldloeffler.tasktracker2006.domain;

import java.io.Serializable;
import javax.xml.bind.annotation.AccessType;
import javax.xml.bind.annotation.XmlAccessorType;

/**
 * Non-persistent Task domain class mapped to XML via JAXB annotations.
 * A Task belongs to exactly one Project.
 * 
 * @author Gerald Loeffler
 */
@XmlAccessorType(AccessType.FIELD)
public class Task implements Serializable {
  private static final long serialVersionUID = 1L;
  
  private Integer id;
  private String  name;
  private String  description;
  private Project project;

  /** Required no-arg constructor (but package-scoped) */
  Task() {}

  /** Minimal constructor */
  public Task(Project project, String name) {
    setProject(project);
    setName(name);
  }

  public Integer getId() {
    return id;
  }

  public String getName() {
    return name;
  }

  private void setName(String name) {
    if (name == null) throw new IllegalArgumentException("name is null");
    this.name = name;
  }

  public String getDescription() {
    return description;
  }

  public void setDescription(String description) {
    this.description = description;
  }

  public Project getProject() {
    return project;
  }

  private void setProject(Project project) {
    if (project == null) throw new IllegalArgumentException("project is null");
    
    // manually ensure relational integrity of of this bidirectional
    // relationship
    if (this.project != null && this.project.getTasks() != null) {
      this.project.getTasks().remove(this);
    }
    this.project = project;
    if (this.project.getTasks() != null) {
      this.project.getTasks().add(this);
    }
  }
  
  @Override
  public String toString() {
    return this.getClass().getSimpleName() + "[id=" + getId() + "]";
  }
}
